@@ -5,8 +5,6 @@ import java.util.Collection;
 
 import gnu.trove.list.array.TDoubleArrayList;
 import gnu.trove.list.array.TIntArrayList;
-import it.unimi.dsi.fastutil.doubles.DoubleArrayList;
-import it.unimi.dsi.fastutil.ints.IntArrayList;
 
 /**
  * A class that contains many generally useful convenience methods.
@@ -26,7 +24,7 @@ public class Tools {
 	public static String StringJoin(ArrayList all, String joinby){
 		if (all == null){
 			return " NULL ARRAY ";
-		}		
+		}
 		return StringJoin(all.toArray(), joinby);
 	}	
 	
@@ -43,12 +41,6 @@ public class Tools {
 		}		
 		return StringJoin(all.toArray(), joinby);
 	}
-	public static String StringJoin(IntArrayList all, String joinby){
-		if (all == null){
-			return " NULL ARRAY ";
-		}		
-		return StringJoin(all.elements(), joinby);
-	}
 	
 	/**
 	 * Joins a collection of strings into one string
@@ -99,9 +91,6 @@ public class Tools {
 	public static String StringJoin(TIntArrayList all){
 		return StringJoin(all.toArray(), ", ");
 	}
-	public static String StringJoin(IntArrayList all){
-		return StringJoin(all.elements(), ", ");
-	}
 	
 	/**
 	 * Joins a collection of strings into one string with commas
@@ -136,9 +125,6 @@ public class Tools {
 	public static String StringJoin(TDoubleArrayList all){
 		return StringJoin(all.toArray(), ", ");
 	}
-	public static String StringJoin(DoubleArrayList all){
-		return StringJoin(all.elements(), ", ");
-	}
 	
 	/**
 	 * Joins a collection of strings into one string with commas
